Changelog
=========


(unreleased)
------------
- Remove __main__.py and some useless file. [Ryan Zhang]
- 1. fix cache bug and improve it to pyarrow 2. improve __init__.py
  export module. [Ryan Zhang]
- Change release target to sdist and dist. [Ryan Zhang]
- Pump version up 0.1.12.dev. [Ryan Zhang]
- Release: version 0.1.12 🚀 [Ryan Zhang]
- Sqlalchemy still require psycopg2-binary. [Ryan Zhang]
- Fix the systest not upgraded. [Ryan Zhang]
- Improve Makefile release target. [Ryan Zhang]
- Improve the release process (fix the 0.1.11 issue when tag. [Ryan
  Zhang]
- Pump version up 0.1.1.dev. [Ryan Zhang]
- Release: version 0.1.1 🚀 [Ryan Zhang]
- Apply fmt and lint. [Ryan Zhang]
- Refactor the code 1. remove psycopg2 deps 2. add get_any_by_any_column
  api 3. use sqlite instead of pg for kupy 4. add execute_sql_file api.
  [Ryan Zhang]
- Improve python dev(snapshot) version. [Ryan Zhang]
- Improve Makefile. [Ryan Zhang]
- Pump version up 0.1.9.dev. [Ryan Zhang]
- Release: version 0.1.9 🚀 [Ryan Zhang]
- Improve Makefile. [Ryan Zhang]
- Start to use dev version  for developement ie 0.1.8-dev, and improve
  the tag process. [Ryan Zhang]
- Replace psycopg2 with -binary. [Ryan Zhang]
- 增加了excute_any_sql 接口. [Ryan Zhang]
- Small change in Makefile. [Ryan Zhang]


0.1.8 (2022-02-06)
------------------
- Release: version 0.1.8 🚀 [Ryan Zhang]
- Fix release target in Makefile. [Ryan Zhang]
- Release: version  🚀 [Ryan Zhang]
- Release: version  🚀 [Ryan Zhang]
- Ready to release 0.1.8. [Ryan Zhang]
- 增加fmt before lint. [Ryan Zhang]
- 增加发布流程, 改进Makefile. [Ryan Zhang]
- Fix a cache_folder initilize error. [Ryan Zhang]
- Small improvement. [Ryan Zhang]
- 增加systest Makefile和增加.pypirc 的配置. [Ryan Zhang]
- Not use camelCase for function name. [Ryan Zhang]
- 增加dbadaptor docstring以及 更改配置项cache_folder为data_folder. [Ryan Zhang]
- Pump version to 0.1.5 修复安装缺requirements.txt. [Ryan Zhang]
- Pump up version to 0.1.2 and upload to pypi. [Ryan Zhang]
- ✅ Ready to clone and code. [ryanzhang]
- Initial commit. [Ryan ZhangCheng]


